// ****************************************************************
// Sketch HttpClient Taster Modular(Tab)
// created: Jens Fleischer, 2019-12-29
// last mod: Jens Fleischer, 2019-12-29
// For more information visit: https://fipsok.de
// ****************************************************************
// Hardware: Esp8266
// D2 = GPIO4  Anschluss Taster vom GPIO4 auf GND
// Software: Esp8266 Arduino Core 2.5.2 - 3.1.1
// Getestet auf: Nodemcu, Wemos D1 Mini Pro
/******************************************************************
  Copyright (c) 2019 Jens Fleischer. All rights reserved.

  This file is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.
  This file is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.
*******************************************************************/
// Diese Version von HttpClient Taster sollte als Tab eingebunden werden.
// #include <ESP8266WebServer.h> oder #include <ESP8266WiFi.h> muss im Haupttab aufgerufen werden
// Zum schalten muss die Funktion "getbutton();" im loop(); aufgerufen werden.
/**************************************************************************************/

#include <ESP8266HTTPClient.h>

constexpr byte BUTTON_PIN = D2;                         // Pin für Taster einstellen
const char* URL = "http://192.168.178.57";          // trage hier die URL deines ESP8266 mit Singel Zeitschaltuhr ein

void getbutton() {                                  // Funktion muss in loop() eingebunden werden
  pinMode(BUTTON_PIN, INPUT_PULLUP);                // oder 10k Pullup-Widerstand von VCC zum inputPIN
  static bool previousStatus {0};
  static uint32_t debounceMillis;
  auto currentMillis = millis();
  if (currentMillis - debounceMillis >= 50) {       // 50 ms Taster Entprellzeit
    debounceMillis = currentMillis;
    bool currentStatus = digitalRead(BUTTON_PIN);
    if (!currentStatus && currentStatus != previousStatus) {
      httpClient("/timer?tog=tog");                 // Funktionsaufruf httpClient mit Query-String
    }
    previousStatus = currentStatus;
  }
}

void httpClient(const char *message) {
  WiFiClient client;
  HTTPClient http;
  if (http.begin(client, (String)URL + message)) {  // für Core Version 2.4.x Zeile ersetzen if (http.begin((String)URL + message)) {
    int16_t httpCode = http.GET();
    if (httpCode > 0) {
      Serial.printf("HTTP / 1.1 %d\n", httpCode);
      if (httpCode == HTTP_CODE_OK) {
        String payload = http.getString();
        Serial.printf("Verbraucher %s\n\n", payload.substring(2, payload.length()).toInt() ? "An" : "Aus");
      }
    }
    else {
      Serial.println("Fehler: " + http.errorToString(httpCode));
    }
    http.end();
  }
}
